@@ -11,7 +11,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.33_03';
+$VERSION = '0.34_02';
 
 %EXPORT_TAGS = (
     'all' => [qw(
@@ -94,7 +94,7 @@ UUID - Universally Unique Identifier library for Perl
     $str = uuid6();                   # new version 6 UUID string
     $str = uuid7();                   # new version 7 UUID string
 
-    # namespace is 'dns', 'url', 'oid', or 'x500', case-insensitive.
+    # NAMESPACE is 'dns', 'url', 'oid', or 'x500'; case-insensitive.
     $str = uuid3(dns => 'www.example.com');
     $str = uuid5(url => 'https://www.example.com/foo.html');
 
@@ -424,6 +424,41 @@ can't predict the future.
 
 Well, that's the theory anyway.
 
+=head1 NAMESPACES
+
+Versions 3 and 5 generate UUIDs within namespaces. What this really
+means is that the I<NAME> value is concatenated with a dedicated
+I<NAMESPACE> UUID before hashing.
+
+Available namespaces and UUIDs:
+
+    dns   6ba7b810-9dad-11d1-80b4-00c04fd430c8
+    url   6ba7b811-9dad-11d1-80b4-00c04fd430c8
+    oid   6ba7b812-9dad-11d1-80b4-00c04fd430c8
+    x500  6ba7b814-9dad-11d1-80b4-00c04fd430c8
+
+For example, if you need to create some UUIDs within your own
+"questions" and "answers" namespaces using SHA1:
+
+    $ns_base = uuid5( dns => 'www.example.com' );
+
+    $ns_questions = uuid5( $ns_base, 'questions' );
+    $ns_answers   = uuid5( $ns_base, 'answers'   );
+
+    for $topic ( next_qa_aref() ) {
+        ($q, $a) = @$topic;
+        $uuid_question = uuid5( $ns_questions, $q );
+        $uuid_answer   = uuid5( $ns_answers,   $a );
+        ...
+    }
+
+This way, you can deterministically convert existing (and likely
+colliding) namespaces over to one UUID namespace, which is often useful
+when merging datasets.
+
+You also don't need to publish your base and namespace UUIDs. Anyone
+using the same logic can generate the same question and answer UUIDs.
+
 =head1 EXPORTS
 
 None by default. All functions may be imported in the usual manner,
