@@ -7,8 +7,9 @@
 #define MAX_ADJUSTMENT 10
 
 void uu_clock_init(pUCXT);
-void uu_init_statepath(pUCXT, const char *path);
-IV   uu_clock(pUCXT, U64 *clock_reg, U16 *ret_clock_seq);
+void uu_clock_getpath(pUCXT, struct_pathlen_t *sp);
+void uu_clock_setpath(pUCXT, struct_pathlen_t *sp);
+IV   uu_clock(pUCXT, U64 *ret_clock_reg, U16 *ret_clock_seq);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
